@@ -7,21 +7,21 @@ extends 'Image::TextMode::Palette';
 has '+colors' => (
     default => sub {
         [   [ 0x00, 0x00, 0x00 ],
-            [ 0x00, 0x00, 0xa8 ],
-            [ 0x00, 0xa8, 0x00 ],
-            [ 0x00, 0xa8, 0xa8 ],
-            [ 0xa8, 0x00, 0x00 ],
-            [ 0xa8, 0x00, 0xa8 ],
-            [ 0xa8, 0x54, 0x00 ],
-            [ 0xa8, 0xa8, 0xa8 ],
-            [ 0x54, 0x54, 0x54 ],
-            [ 0x54, 0x54, 0xfc ],
-            [ 0x54, 0xfc, 0x54 ],
-            [ 0x54, 0xfc, 0xfc ],
-            [ 0xfc, 0x54, 0x54 ],
-            [ 0xfc, 0x54, 0xfc ],
-            [ 0xfc, 0xfc, 0x54 ],
-            [ 0xfc, 0xfc, 0xfc ],
+            [ 0x00, 0x00, 0xaa ],
+            [ 0x00, 0xaa, 0x00 ],
+            [ 0x00, 0xaa, 0xaa ],
+            [ 0xaa, 0x00, 0x00 ],
+            [ 0xaa, 0x00, 0xaa ],
+            [ 0xaa, 0x55, 0x00 ],
+            [ 0xaa, 0xaa, 0xaa ],
+            [ 0x55, 0x55, 0x55 ],
+            [ 0x55, 0x55, 0xff ],
+            [ 0x55, 0xff, 0x55 ],
+            [ 0x55, 0xff, 0xff ],
+            [ 0xff, 0x55, 0x55 ],
+            [ 0xff, 0x55, 0xff ],
+            [ 0xff, 0xff, 0x55 ],
+            [ 0xff, 0xff, 0xff ],
         ];
     }
 );
@@ -44,7 +44,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2010 by Brian Cassidy
+Copyright 2008-2011 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
